==> haskell-kan-extensions-5.0.1-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-JxnJF79ehCQ1iWfDSDGjll
key: kan-extensions-5.0.1-JxnJF79ehCQ1iWfDSDGjll
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
abi: ac081a8dbbd33457f7c8a9fc8c0de742
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-JxnJF79ehCQ1iWfDSDGjll
depends:
    adjunctions-4.3-DdaVzHtQIdKKcIMAtenkpN array-0.5.1.1 base-4.9.0.0
    comonad-5-1roHbXsedY6KUNYFgPJLp6 containers-0.5.7.1
    contravariant-1.4-89BvpwBnlCJ6iFzBGVF7XO
    distributive-0.5.0.2-2AokE99FpE59iSGkvIRYC4
    free-4.12.4-LcxMyZIxIoo6h2gqXah9QK mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    semigroupoids-5.1-5WI5yrkqR6b5vppUpisNlN
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.0.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-78ACqWhn4sfAX5y1tW3z29
key: kan-extensions-5.0.1-78ACqWhn4sfAX5y1tW3z29
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
abi: 55e5f7f77431ef5d40fb36847585176a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-78ACqWhn4sfAX5y1tW3z29
depends:
    adjunctions-4.3-BfmmbR5OgFBEUx5qk17tC7 array-0.5.1.1 base-4.9.0.0
    comonad-5-32c0CBnUQitJOjClwXgxTu containers-0.5.7.1
    contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    distributive-0.5.1-BXBEYSWODmEIzmEEO7ASAJ
    free-4.12.4-Aed7uNZqrKqF7XkiVApgap mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    semigroupoids-5.1-DzcNuJqpBH92pXLHWsg7Nu
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
